import React, { useState, useEffect } from 'react'
import withLayout from '@/layout'
import './index.scss'
import IndexBanner from './components/IndexBanner/index'
import IndexMenu from './components/IndexMenu/index'
import SubBanner from './components/SubBanner/index'
import IndexColumnTitle from './components/IndexColumnTitle/index'
import IndexHotActivity from './components/IndexHotActivity/index'
import ProjectListItem from '../../components/ProjectListItem/index'
import { ScrollView } from '@tarojs/components'

export default withLayout((props) => {

  // const [PageProps] = useState(props)
  const [BannerList, setBannerList] = useState(['', '', ''])
  const [MenuList, setMenuList] = useState(['', '', '', '', '', '', '', '', '', ''])
  const [SubBannerList, setSubBannerList] = useState(['', '', ''])
  const [ProjectList, setProjectList] = useState(['', '', ''])
  const [IsPull, setPull] = useState(false)
  const [PullTimer, setPullTimer] = useState(null)

  const PageRefresh = () => { // 页面下拉刷新回调
    setPull(true)
  }

  useEffect(() => { // 下拉刷新触发
    if (IsPull) {
      clearTimeout(PullTimer)
      setPullTimer(setTimeout(() => {
        setPull(false)
      }, 2000))
    }
  }, [IsPull])

  return (
    <view className='Page Index'>

      <ScrollView scroll-y={true} refresher-enabled={true} refresher-triggered={IsPull} onrefresherrefresh={PageRefresh} refresher-background='#fff'>
        <view className='PageContent'>

          {/* banner */}
          <view className='Banner'>
            <view>
              <view>
                <IndexBanner List={BannerList}></IndexBanner>
              </view>
            </view>
          </view>

          {/* menu */}
          <view className='IndexMenu'>
            <view>
              <IndexMenu List={MenuList}></IndexMenu>
            </view>
          </view>

          {/* sub banner */}
          <view className='SubBanner'>
            <view>
              <view>
                <SubBanner List={SubBannerList}></SubBanner>
              </view>
            </view>
          </view>

          {/* hot activity */}
          <view className='HotActivity'>
            <IndexColumnTitle Name='热门活动'></IndexColumnTitle>
            <IndexHotActivity List={['', '', '']}></IndexHotActivity>
          </view>

          {/* all project */}
          <view className='AllProject'>
            <IndexColumnTitle Name='所有项目'>
              <view className='ToMap'>
                <text className='iconfont'></text>
                <text>地图找房</text>
              </view>
            </IndexColumnTitle>
            <view className='ProjectList'>
              {
                ProjectList.map((item, index) => (
                  <ProjectListItem Data={item} key={`ProjectListItem-${index}`}></ProjectListItem>
                ))
              }
            </view>
          </view>

          {/* bottom */}
          <view className='PageBottom'>
            <text>已经到底了~</text>
          </view>

        </view>
      </ScrollView>

    </view>
  )
})
